/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if !defined(_DATA_COMMON_H)
#define _DATA_COMMON_H

#include <time.h>
#include <contacts.h>

#define CONTACTS_LIST_FOREACH(list, record) \
	bool success = (contacts_list_get_current_record_p(list, &record) == CONTACTS_ERROR_NONE); \
	for ( ; success; \
		success = ((contacts_list_next(list) == CONTACTS_ERROR_NONE) \
		&& (contacts_list_get_current_record_p(list, &record) == CONTACTS_ERROR_NONE)) \
		)

typedef enum {CF_FIRST_NAME, CF_LAST_NAME, CF_PHONE_NUMBER, CF_EMAIL, CF_URL, CF_COMPANY, CF_BIRTHDAY, CF_NOTE, CF_MAX} sc_common_contact_fields;

bool data_common_connect(void);
bool data_common_disconnect(void);
bool data_common_create_record(const char *uri, contacts_record_h *rec_h);
bool data_common_insert_record(contacts_record_h rec_h, int *id);
bool data_common_update_record(contacts_record_h rec_h);
bool data_common_get_record(const char *uri, int id, contacts_record_h *rec_h);
bool data_common_get_all_records(const char *uri, contacts_list_h *list_h);
bool data_common_get_record_child(contacts_record_h parent_h, int parent_id, contacts_record_h *rec_h);
bool data_common_add_record_child(contacts_record_h parent_h, const char *uri, int parent_id, contacts_record_h *rec_h);
bool data_common_get_bool(contacts_record_h rec_h, int id, bool *value);
bool data_common_get_int(contacts_record_h rec_h, int id, int *value);
bool data_common_get_str(contacts_record_h rec_h, int id, char **value);
bool data_common_set_bool(contacts_record_h rec_h, int id, bool value);
bool data_common_set_int(contacts_record_h rec_h, int id, int value);
bool data_common_set_str(contacts_record_h rec_h, int id, const char *value);
bool data_common_create_list(contacts_list_h *list_h);
bool data_common_get_list_count(contacts_list_h list_h, int *count);
bool data_common_set_list_first(contacts_list_h list_h);
bool data_common_add_list_record(contacts_list_h list_h, contacts_record_h rec_h);
const char *data_common_get_field_name(sc_common_contact_fields field_type);
void data_common_get_contact_properties(sc_common_contact_fields field_type, unsigned *parent_property_id, const char **child_uri, unsigned *child_property_id);
struct tm data_common_int_to_date(int date_value);
char *data_common_date_to_str(struct tm *date);
char *data_common_trim(const char *str);
contacts_list_h data_common_get_int_records(const char *table_uri, unsigned filter_field, int filter_val);
contacts_list_h data_common_get_str_records(const char *table_uri, unsigned filter_field, const char *filter_val);
contacts_list_h data_common_get_bool_records(const char *table_uri, unsigned filter_field, bool filter_val);

#endif
