/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "contacts_app.h"
#include "view/view_common.h"

/**
 * @brief Returns to certain view.
 * @param[in] obj Evas object wherein stored information to what view return.
 * @param[in] view_item Naviframe item view to return.
 */
void view_common_return_to_view(Evas_Object *obj, sc_view_common_view_item view_item)
{
	const char *item_str_key = NULL;
	Elm_Object_Item *navi_item;

	if (view_item < VI_PERSON_LIST || view_item >= VI_MAX) {
		dlog_print(DLOG_ERROR, LOG_TAG, "sc_view_common_return_to_view() failed. Invalid input argument.");
		return;
	}

	switch (view_item) {
	case VI_PERSON_LIST:
		item_str_key = "person_list_item";
		break;
	case VI_CATEGORIES_LIST:
		item_str_key = "categories_list_item";
		break;
	case VI_MAX: /* Max value is not used */
		break;
	default:
		break;
	}

	navi_item = evas_object_data_get(obj, item_str_key);
	if (!navi_item) {
		dlog_print(DLOG_ERROR, LOG_TAG, "evas_object_data_get() failed.");
		return;
	}

	elm_naviframe_item_pop_to(navi_item);
}
